==> jexpress-2.3.0-sources.jar: org/summerboot/jexpress/security/auth/Authenticator.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.security.auth;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import io.netty.handler.codec.http.HttpHeaders;
import javax.naming.NamingException;
import org.summerboot.jexpress.integration.cache.AuthTokenCache;
import org.summerboot.jexpress.nio.server.RequestProcessor;
import org.summerboot.jexpress.nio.server.domain.ServiceContext;

/**
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public interface Authenticator {

    //<T extends BootCache> void setCache(T cache);
    /**
     *
     * @param listener
     */
    void setListener(AuthenticatorListener listener);

    /**
     * Success HTTP Status: 201 Created
     *
     * @param uid
     * @param pwd
     * @param metaData
     * @param validForMinutes
     * @param context
     * @return JWT
     * @throws javax.naming.NamingException
     */
    String login(String uid, String pwd, Object metaData, int validForMinutes, final ServiceContext context) throws NamingException;

    JwtBuilder toJwt(Caller caller);

    Caller fromJwt(Claims claims);

    /**
     * Retrieve token based on RFC 6750 - The OAuth 2.0 Authorization Framework
     * override this method to get customized token
     *
     * @param httpRequestHeaders
     * @return
     */
    String getBearerToken(HttpHeaders httpRequestHeaders);

    /**
     * Success HTTP Status: 200 OK
     *
     * @param <T>
     * @param httpRequestHeaders contains Authorization = Bearer + JWT
     * @param cache
     * @param errorCode
     * @param context
     * @return Caller
     */
    <T extends Caller> T verifyBearerToken(HttpHeaders httpRequestHeaders, AuthTokenCache cache, Integer errorCode, final ServiceContext context);
    
    /**
     * do any validation checks before processing
     *
     * @param processor
     * @param httpRequestHeaders
     * @param httpRequestPath
     * @param context
     * @return true if good to process request, otherwise false
     * @throws Exception
     */
    boolean preAccessCheck(RequestProcessor processor, HttpHeaders httpRequestHeaders, String httpRequestPath, ServiceContext context) throws Exception;

    /**
     *
     * @param <T>
     * @param authToken
     * @param cache
     * @param errorCode
     * @param context
     * @return Caller
     */
    <T extends Caller> T verifyToken(String authToken, AuthTokenCache cache, Integer errorCode, final ServiceContext context);

    /**
     * Success HTTP Status: 204 No Content
     *
     * @param httpRequestHeaders contains Authorization = Bearer + JWT
     * @param cache
     * @param context
     */
    void logout(HttpHeaders httpRequestHeaders, AuthTokenCache cache, final ServiceContext context);

    /**
     * Success HTTP Status: 204 No Content
     *
     * @param authToken
     * @param cache
     * @param context
     */
    void logout(String authToken, AuthTokenCache cache, final ServiceContext context);
}

==> jexpress-2.3.4-sources.jar: org/summerboot/jexpress/security/auth/Authenticator.java <==
/*
 * Copyright 2005-2022 Du Law Office - The Summer Boot Framework Project
 *
 * The Summer Boot Project licenses this file to you under the Apache License, version 2.0 (the
 * "License"); you may not use this file except in compliance with the License and you have no
 * policy prohibiting employee contributions back to this file (unless the contributor to this
 * file is your current or retired employee). You may obtain a copy of the License at:
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.summerboot.jexpress.security.auth;

import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtBuilder;
import io.netty.handler.codec.http.HttpHeaders;
import javax.naming.NamingException;
import org.summerboot.jexpress.integration.cache.AuthTokenCache;
import org.summerboot.jexpress.nio.server.RequestProcessor;
import org.summerboot.jexpress.nio.server.domain.ServiceContext;

/**
 *
 * @author Changski Tie Zheng Zhang 张铁铮, 魏泽北, 杜旺财, 杜富贵
 */
public interface Authenticator {

    //<T extends BootCache> void setCache(T cache);
    /**
     *
     * @param listener
     */
    void setListener(AuthenticatorListener listener);

    /**
     * Success HTTP Status: 201 Created
     *
     * @param username
     * @param pwd
     * @param metaData
     * @param validForMinutes
     * @param context
     * @return JWT
     * @throws javax.naming.NamingException
     */
    String login(String username, String pwd, Object metaData, int validForMinutes, final ServiceContext context) throws NamingException;

    /**
     * Extra authorization checks before processing
     *
     * @param processor
     * @param httpRequestHeaders
     * @param httpRequestPath
     * @param context
     * @return true if good to process request, otherwise false
     * @throws Exception
     */
    boolean customizedAuthorizationCheck(RequestProcessor processor, HttpHeaders httpRequestHeaders, String httpRequestPath, ServiceContext context) throws Exception;

    JwtBuilder toJwt(Caller caller);

    Caller fromJwt(Claims claims);

    /**
     * Retrieve token based on RFC 6750 - The OAuth 2.0 Authorization Framework
     * override this method to get customized token
     *
     * @param httpRequestHeaders
     * @return
     */
    String getBearerToken(HttpHeaders httpRequestHeaders);

    /**
     * Success HTTP Status: 200 OK
     *
     * @param <T>
     * @param httpRequestHeaders contains Authorization = Bearer + JWT
     * @param cache
     * @param errorCode
     * @param context
     * @return Caller
     */
    <T extends Caller> T verifyBearerToken(HttpHeaders httpRequestHeaders, AuthTokenCache cache, Integer errorCode, final ServiceContext context);

    /**
     *
     * @param <T>
     * @param authToken
     * @param cache
     * @param errorCode
     * @param context
     * @return Caller
     */
    <T extends Caller> T verifyToken(String authToken, AuthTokenCache cache, Integer errorCode, final ServiceContext context);

    /**
     * Success HTTP Status: 204 No Content
     *
     * @param httpRequestHeaders contains Authorization = Bearer + JWT
     * @param cache
     * @param context
     */
    void logout(HttpHeaders httpRequestHeaders, AuthTokenCache cache, final ServiceContext context);

    /**
     * Success HTTP Status: 204 No Content
     *
     * @param authToken
     * @param cache
     * @param context
     */
    void logout(String authToken, AuthTokenCache cache, final ServiceContext context);
}
